#!/usr/bin/env python

#-----------------------------------------------------------------------
# penny.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import html # html_code.escape() is used to thwart XSS attacks
import flask
import common
import database

#-----------------------------------------------------------------------

app = flask.Flask(__name__)

#-----------------------------------------------------------------------

@app.route('/', methods=['GET'])
@app.route('/index', methods=['GET'])
def index():

    html_code = ''
    html_code += '<!DOCTYPE html>'
    html_code += '<html>'
    html_code += '<head>'
    html_code += '<title>Penny.com</title>'
    html_code += '</head>'
    html_code += '<body>'
    html_code += common.get_header()
    html_code += '<br>'
    html_code += 'Click here to <a href="/searchform">begin</a>.<br>'
    html_code += '<br>'
    html_code += common.get_footer()
    html_code += '</body>'
    html_code += '</html>'

    response = flask.make_response(html_code)
    return response

#-----------------------------------------------------------------------

@app.route('/searchform', methods=['GET'])
def search_form():

    prev_author = flask.request.cookies.get('prev_author')
    if prev_author is None:
        prev_author = '(None)'

    html_code = ''
    html_code += '<!DOCTYPE html>'
    html_code += '<html>'
    html_code += '<head>'
    html_code += '<title>Penny.com</title>'
    html_code += '</head>'
    html_code += '<body>'
    html_code += common.get_header()
    html_code += '<h1>Author Search</h1>'
    html_code += '<form action="/searchresults" method="get">'
    html_code += 'Please enter an author name:'
    html_code += '<input type="text" name="author" autofocus>'
    html_code += '<input type="submit" value="Go">'
    html_code += '</form>'
    html_code += '<br>'
    html_code += '<br>'
    html_code += '<strong>Previous author search:</strong> '
    html_code += html.escape(prev_author)
    html_code += '<br>'
    html_code += '<br>'
    html_code += common.get_footer()
    html_code += '</body>'
    html_code += '</html>'

    response = flask.make_response(html_code)
    return response

#-----------------------------------------------------------------------

@app.route('/searchresults', methods=['GET'])
def search_results():

    author = flask.request.args.get('author')
    if author is None:
        author = ''
    author = author.strip()

    if author == '':
        prev_author = '(None)'
        books = []
    else:
        prev_author = author
        books = database.get_books(author) # Exception handling omitted

    html_code = ''
    html_code += '<!DOCTYPE html>'
    html_code += '<html>'
    html_code += '<head>'
    html_code += '<title>Penny.com</title>'
    html_code += '</head>'
    html_code += '<body>'
    html_code += common.get_header()
    html_code += '<h1>Author Search Results</h1>'
    html_code += '<h2>Books by ' + html.escape(prev_author) + ':</h2>'

    if len(books) == 0:
        html_code += '(None)<br>'
    else:
        pattern = '%s: <strong>%s</strong>: %s<br>'
        for book in books:
            html_code += pattern % (book['isbn'], book['author'],
                book['title'])

    html_code += '<br>'
    html_code += '<br>'
    html_code += 'Click here to do another '
    html_code += '<a href="/searchform">author search</a>.'
    html_code += '<br>'
    html_code += '<br>'
    html_code += '<br>'
    html_code += '<br>'
    html_code += common.get_footer()
    html_code += '</body>'
    html_code += '</html>'

    response = flask.make_response(html_code)
    response.set_cookie('prev_author', prev_author)
    return response
