#!/usr/bin/env python

#-----------------------------------------------------------------------
# penny.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import http.cookies
import html
import common
import parseargs
import database

def index(environ, start_response):

    html_code = ''
    html_code += '<!DOCTYPE html>'
    html_code += '<html>'
    html_code += '<head>'
    html_code += '<title>Penny.com</title>'
    html_code += '</head>'
    html_code += '<body>'
    html_code += common.get_header()
    html_code += '<br>'
    html_code += 'Click here to <a href="/searchform">begin</a>.<br>'
    html_code += '<br>'
    html_code += common.get_footer()
    html_code += '</body>'
    html_code += '</html>'

    content_header = ('content-type', 'text/html; charset=utf-8')
    headers = [content_header]
    start_response('200 OK', headers)
    return [html_code.encode('utf-8')]

def search_form(environ, start_response):

    prev_author = '(None)'
    if 'HTTP_COOKIE' in environ:
        cookie = http.cookies.SimpleCookie(environ['HTTP_COOKIE'])
        if 'prev_author' in cookie:
            prev_author_morsel = cookie['prev_author']
            if prev_author_morsel:
                prev_author = prev_author_morsel.value

    html_code = ''
    html_code += '<!DOCTYPE html>'
    html_code += '<html>'
    html_code += '<head>'
    html_code += '<title>Penny.com</title>'
    html_code += '</head>'
    html_code += '<body>'
    html_code += common.get_header()
    html_code += '<h1>Author Search</h1>'
    html_code += '<form action="/searchresults" method="get">'
    html_code += 'Please enter an author name:'
    html_code += '<input type="text" name="author" autofocus>'
    html_code += '<input type="submit" value="Go">'
    html_code += '</form>'
    html_code += '<br>'
    html_code += '<br>'
    html_code += '<strong>Previous author search:</strong> '
    html_code += html.escape(prev_author)
    html_code += '<br>'
    html_code += '<br>'
    html_code += common.get_footer()
    html_code += '</body>'
    html_code += '</html>'

    content_header = ('content-type', 'text/html; charset=utf-8')
    headers = [content_header]
    start_response('200 OK', headers)
    return [html_code.encode('utf-8')]

def search_results(environ, start_response):

    args_str = environ.get('QUERY_STRING', '')
    args = parseargs.parse(args_str)
    author = args.get('author', '')

    author = author.strip()

    if author == '':
        prev_author = '(None)'
        books = []
    else:
        prev_author = author
        books = database.get_books(author) # Exception handling omitted

    html_code = ''
    html_code += '<!DOCTYPE html>'
    html_code += '<html>'
    html_code += '<head>'
    html_code += '<title>Penny.com</title>'
    html_code += '</head>'
    html_code += '<body>'
    html_code += common.get_header()
    html_code += '<h1>Author Search Results</h1>'
    html_code += '<h2>Books by ' + html.escape(prev_author) + ':</h2>'

    if len(books) == 0:
        html_code += '(None)<br>'
    else:
        pattern = '%s: <strong>%s</strong>: %s<br>'
        for book in books:
            html_code += pattern % (book['isbn'], book['author'],
                book['title'])
    html_code += '<br>'
    html_code += '<br>'
    html_code += 'Click here to do another '
    html_code += '<a href="/searchform">author search</a>.'
    html_code += '<br>'
    html_code += '<br>'
    html_code += '<br>'
    html_code += '<br>'
    html_code += common.get_footer()
    html_code += '</body>'
    html_code += '</html>'

    content_header = ('content-type', 'text/html; charset=utf-8')
    cookie = http.cookies.SimpleCookie()
    cookie['prev_author'] = prev_author
    cookie_header = ('Set-Cookie', cookie['prev_author'].OutputString())
    headers = [content_header, cookie_header]
    start_response('200 OK', headers)
    return [html_code.encode('utf-8')]

def not_found(environ, start_response):

    # This is the response generated by Flask applications.
    html_code = ''
    html_code += '<!DOCTYPE html>'
    html_code += '<title>404 Not Found</title>'
    html_code += '<h1>Not Found</h1>'
    html_code += '<p>The requested URL was not found on the server. '
    html_code += 'If you entered the URL manually please check your '
    html_code += 'spelling and try again.</p>'

    content_header = ('content-type', 'text/html; charset=utf-8')
    headers = [content_header]
    start_response('200 OK', headers)
    return [html_code.encode('utf-8')]

def app(environ, start_response):

    path = environ.get('PATH_INFO', '').strip('/')

    if path in ('', 'index'):
        return index(environ, start_response)
    if path == 'searchform':
        return search_form(environ, start_response)
    if path == 'searchresults':
        return search_results(environ, start_response)

    return not_found(environ, start_response)
